@@ -28,7 +28,7 @@ class RestCLIClient:
         self.conn = http.client.HTTPConnection(connectionIP, connectionPort)
 
     def check_response(self, response):
-        if response == b'200':
+        if response.code == 200:
             return True
         else:
             return False
